@@ -28,6 +28,8 @@ namespace KIO
 
 class TransferJobPrivate;
 /**
+ * @class KIO::TransferJob transferjob.h <KIO/TransferJob>
+ *
  * The transfer job pumps data into and/or out of a Slave.
  * Data is sent to the slave on request of the slave ( dataReq).
  * If data coming from the slave can not be handled, the
@@ -38,7 +40,7 @@ class KIOCORE_EXPORT TransferJob : public SimpleJob
     Q_OBJECT
 
 public:
-    ~TransferJob();
+    ~TransferJob() Q_DECL_OVERRIDE;
 
     /**
      * Sets the modification time of the file to be created (by KIO::put)
@@ -72,7 +74,7 @@ public:
 
     /**
      * When enabled, the job reports the amount of data that has been sent,
-     * instead of the amount of data that that has been received.
+     * instead of the amount of data that has been received.
      * @see slotProcessedSize
      * @see slotSpeed
      * @deprecated since 4.2.1, this is unnecessary (it is always false for
@@ -204,6 +206,7 @@ private:
     Q_PRIVATE_SLOT(d_func(), void slotSubUrlData(KIO::Job *, const QByteArray &))
     Q_PRIVATE_SLOT(d_func(), void slotDataReqFromDevice())
     Q_PRIVATE_SLOT(d_func(), void slotIODeviceClosed())
+    Q_PRIVATE_SLOT(d_func(), void slotIODeviceClosedBeforeStart())
     Q_DECLARE_PRIVATE(TransferJob)
 
     // A FileCopyJob may control one or more TransferJobs
