@@ -27,8 +27,8 @@
 
 #include <config-kioslave-file.h>
 
-#include <QtCore/QFile>
-#include <QtCore/QDir>
+#include <QFile>
+#include <QDir>
 #include <qplatformdefs.h>
 
 #include <QDebug>
@@ -37,6 +37,9 @@
 #include <kmountpoint.h>
 
 #include <errno.h>
+#if HAVE_SYS_XATTR_H
+#include <sys/xattr.h>
+#endif
 #include <utime.h>
 
 #include <KAuth>
@@ -410,6 +413,52 @@ static bool isLocalFileSameHost(const QUrl &url)
     return (QString::compare(url.host(), QLatin1String(hostname), Qt::CaseInsensitive) == 0);
 }
 
+#if HAVE_SYS_XATTR_H
+static bool isNtfsHidden(const QString &filename)
+{
+    constexpr auto attrName = "system.ntfs_attrib_be";
+    const auto filenameEncoded = QFile::encodeName(filename);
+#ifdef Q_OS_MACOS
+    auto length = getxattr(filenameEncoded.data(), attrName, nullptr, 0, 0, XATTR_NOFOLLOW);
+#else
+    auto length = getxattr(filenameEncoded.data(), attrName, nullptr, 0);
+#endif
+    if (length <= 0) {
+        return false;
+    }
+    constexpr size_t xattr_size = 1024;
+    char strAttr[xattr_size];
+#ifdef Q_OS_MACOS
+    length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size, 0, XATTR_NOFOLLOW);
+#else
+    length = getxattr(filenameEncoded.data(), attrName, strAttr, xattr_size);
+#endif
+    if (length <= 0) {
+        return false;
+    }
+
+    // Decode result to hex string
+    static constexpr auto digits = "0123456789abcdef";
+    QVarLengthArray<char> hexAttr(static_cast<int>(length) * 2 + 4);
+    char *c = strAttr;
+    char *e = hexAttr.data();
+    *e++ ='0';
+    *e++ = 'x';
+    for (auto n = 0; n < length; n++, c++) {
+        *e++ = digits[(static_cast<uchar>(*c) >> 4)];
+        *e++ = digits[(static_cast<uchar>(*c) & 0x0F)];
+    }
+    *e = '\0';
+
+    // Decode hex string to int
+    auto intAttr = static_cast<uint>(strtol(hexAttr.data(), nullptr, 16));
+
+    constexpr auto FILE_ATTRIBUTE_HIDDEN = 0x2u;
+    return static_cast<bool>(intAttr & FILE_ATTRIBUTE_HIDDEN);
+}
+#endif
+
+
 void FileProtocol::listDir(const QUrl &url)
 {
     if (!isLocalFileSameHost(url)) {
@@ -506,6 +555,11 @@ void FileProtocol::listDir(const QUrl &url)
 
         } else {
             if (createUDSEntry(filename, QByteArray(ep->d_name), entry, details)) {
+#if HAVE_SYS_XATTR_H
+                if (isNtfsHidden(filename)) {
+                    entry.insert(KIO::UDSEntry::UDS_HIDDEN, 1);
+                }
+#endif
                 listEntry(entry);
             }
         }
@@ -801,7 +855,8 @@ PrivilegeOperationReturnValue FileProtocol::execWithElevatedPrivilege(ActionType
         out << arg;
     }
 
-    KAuth::Action execAction(QStringLiteral("org.kde.kio.file.exec"));
+    const QString actionId = QStringLiteral("org.kde.kio.file.exec");
+    KAuth::Action execAction(actionId);
     execAction.setHelperId(QStringLiteral("org.kde.kio.file"));
 
     QVariantMap argv;
@@ -810,6 +865,7 @@ PrivilegeOperationReturnValue FileProtocol::execWithElevatedPrivilege(ActionType
 
     auto reply = execAction.execute();
     if (reply->exec()) {
+        addTemporaryAuthorization(actionId);
         return PrivilegeOperationReturnValue::success();
     }
 
